==> opennms-webapp-1.3.3-sources.jar: org/opennms/web/vulnerability/VulnerabilityQueryParms.java <==
//
// This file is part of the OpenNMS(R) Application.
//
// OpenNMS(R) is Copyright (C) 2002-2003 The OpenNMS Group, Inc.  All rights reserved.
// OpenNMS(R) is a derivative work, containing both original code, included code and modified
// code that was published under the GNU General Public License. Copyrights for modified 
// and included code are below.
//
// OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
//
// Copyright (C) 1999-2001 Oculan Corp.  All rights reserved.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// For more information contact:
//      OpenNMS Licensing       <license@opennms.org>
//      http://www.opennms.org/
//      http://www.opennms.com/
//

package org.opennms.web.vulnerability;

import java.util.ArrayList;

import org.opennms.web.vulnerability.filter.Filter;

/**
 * Convenience data structure for holding the arguments to an vulnerability
 * query.
 * 
 * @author <A HREF="mailto:larry@opennms.org">Lawrence Karnowski </A>
 * @author <A HREF="http://www.opennms.org/">OpenNMS </A>
 */
public class VulnerabilityQueryParms extends Object {
    public VulnerabilityFactory.SortStyle sortStyle;

    public VulnerabilityFactory.ResolutionType resType;

    public ArrayList filters;

    public int limit;

    public int multiple;

    /**
     * Convert the internal (and useful) ArrayList filters object into an array
     * of Filter instances.
     */
    public Filter[] getFilters() {
        Filter[] filters = new Filter[this.filters.size()];
        filters = (Filter[]) this.filters.toArray(filters);
        return (filters);
    }
}

==> opennms-webapp-1.7.3-sources.jar: org/opennms/web/vulnerability/VulnerabilityQueryParms.java <==
//
// This file is part of the OpenNMS(R) Application.
//
// OpenNMS(R) is Copyright (C) 2002-2003 The OpenNMS Group, Inc.  All rights reserved.
// OpenNMS(R) is a derivative work, containing both original code, included code and modified
// code that was published under the GNU General Public License. Copyrights for modified 
// and included code are below.
//
// OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
//
// Modifications:
//
// 2007 Jul 24: Java 5 generics. - dj@opennms.org
//
// Copyright (C) 1999-2001 Oculan Corp.  All rights reserved.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// For more information contact:
//      OpenNMS Licensing       <license@opennms.org>
//      http://www.opennms.org/
//      http://www.opennms.com/
//

package org.opennms.web.vulnerability;

import java.util.List;

import org.opennms.web.vulnerability.filter.Filter;

/**
 * Convenience data structure for holding the arguments to an vulnerability
 * query.
 * 
 * @author <A HREF="mailto:larry@opennms.org">Lawrence Karnowski </A>
 * @author <A HREF="http://www.opennms.org/">OpenNMS </A>
 */
public class VulnerabilityQueryParms extends Object {
    public VulnerabilityFactory.SortStyle sortStyle;

    public VulnerabilityFactory.ResolutionType resType;

    public List<Filter> filters;

    public int limit;

    public int multiple;

    /**
     * Convert the internal (and useful) ArrayList filters object into an array
     * of Filter instances.
     */
    public Filter[] getFilters() {
        return this.filters.toArray(new Filter[this.filters.size()]);
    }
}
